@@ -72,7 +72,7 @@ __END__
 
 =head1 NAME
 
-Weather::NWS::TropicalCyclone
+Weather::NHC::TropicalCyclone
 
 =head1 SYNOPSIS
 
@@ -108,7 +108,7 @@ the JSON provided by the NHC describing the current set of active storms.
 If the JSON is malformed or otherwise can't be parsed, C<fetch> will throw
 an exception.
 
-Fetch will time out after C<$Weather::NWS::TropicalCyclone::DEFAULT_TIMEOUT> by
+Fetch will time out after C<$Weather::NHC::TropicalCyclone::DEFAULT_TIMEOUT> by
 throwing an exception. In order to disable the alarm, call C<fetch> with a
 parameter of 0:
 
